@@ -14,8 +14,10 @@
 #' addin_chatgpt_in_source()
 #' }
 addin_chatgpt_in_source <- function() {
+  cli_process_start("Sending query to ChatGPT")
   gpt_chat_in_source(
     style = getOption("gptstudio.code_style"),
     skill = getOption("gptstudio.skill")
   )
+  cli_process_done()
 }
