@@ -7,4 +7,4 @@
 #' @importFrom assertthat assert_that is.string is.number is.count
 #' @importFrom glue glue
 ## gptstudio namespace: end
-NULL
+gptstudio_env <- new.env()
